"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AwsSecretManager = void 0;
const aws_sdk_1 = require("aws-sdk");
class AwsSecretManager {
    static getInstance() {
        if (!AwsSecretManager.instance) {
            const instance = new AwsSecretManager();
            instance.awsSecretManagerClient = new aws_sdk_1.SecretsManager({
                region: process.env.AWS_REGION,
            });
            AwsSecretManager.instance = instance;
        }
        return AwsSecretManager.instance;
    }
    async getSecret(secretName) {
        return new Promise((resolve, reject) => {
            this.awsSecretManagerClient.getSecretValue({ SecretId: secretName }, (error, data) => {
                if (error) {
                    return reject(error);
                }
                let secret;
                if ('SecretString' in data) {
                    secret = data.SecretString;
                }
                else {
                    secret = Buffer.from(data.SecretBinary, 'base64').toString('ascii');
                }
                resolve(JSON.parse(secret));
            });
        });
    }
}
exports.AwsSecretManager = AwsSecretManager;
